##  Monitor Data Quality on the Architecture Executive Dashboard
The architecture executive dashboard provides predefined key performance indicators (KPIs) for various use cases. To monitor data quality, use KPIs from the following groups:
  * Data Quality: Monitor fact sheet ownership, application lifecycle, quality seal approval, and other KPIs.
  * Application Portfolio Assessment: Track the completion of key application attributes and monitor overall portfolio metrics.


Drill down to KPI details for a more in-depth analysis. You can configure the dashboard to select the KPIs you need. To learn how to use the dashboard, see [Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "The architecture executive dashboard provides essential KPIs related to the organization’s IT landscape, enabling informed, data-driven decision-making through valuable insights.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio6f9405d844fd45588b76309e92006ead_LowRes.png)
KPIs for Application Portfolio Assessment on the Architecture Executive Dashboard
